@@ -64,6 +64,9 @@ def load_obj(file_obj,
     # same logic even if they jump directly in to data lines
     text = '\n{}\n'.format(text.strip().replace('\r\n', '\n'))
 
+    # remove backslash continuation characters and merge them into the same line
+    text = text.replace('\\\n', '')
+
     # Load Materials
     materials = {}
     mtl_position = text.find('mtllib')
@@ -100,6 +103,16 @@ def load_obj(file_obj,
     if group_material:
         face_tuples = _group_by_material(face_tuples)
 
+    # no faces but points given
+    # return point cloud
+    if not len(face_tuples) and v is not None:
+        pc = {'vertices': v}
+        if vn is not None:
+            pc['vertex_normals'] = vn
+        if vc is not None:
+            pc['vertex_colors'] = vc
+        return pc
+
     # Load Faces
     # now we have clean- ish faces grouped by material and object
     # so now we have to turn them into numpy arrays and kwargs
@@ -127,8 +140,10 @@ def load_obj(file_obj,
 
         # the fastest way to get to a numpy array
         # processes the whole string at once into a 1D array
+        array = np.fromstring(joined, sep=' ', dtype=np.int64)
         # also wavefront is 1-indexed (vs 0-indexed) so offset
-        array = np.fromstring(joined, sep=' ', dtype=np.int64) - 1
+        # only applies to positive indices
+        array[array > 0] -= 1
 
         # get the number of raw 2D columns in a sample line
         columns = len(face_lines[0].strip().replace('/', ' ').split())
@@ -203,7 +218,7 @@ def load_obj(file_obj,
             else:
                 # generate the mask so we only include
                 # referenced vertices in every new mesh
-                mask_v = np.zeros(len(v), dtype=np.bool)
+                mask_v = np.zeros(len(v), dtype=bool)
                 mask_v[faces] = True
 
                 # reconstruct the faces with the new vertex indices
@@ -216,13 +231,22 @@ def load_obj(file_obj,
             # start with vertices and faces
             mesh.update({'faces': new_faces,
                          'vertices': v[mask_v].copy()})
-            # if vertex colors are OK save them
-            if vc is not None:
-                mesh['vertex_colors'] = vc[mask_v]
-            # if vertex normals are OK save them
-            if mask_vn is not None:
-                mesh['vertex_normals'] = vn[mask_vn]
 
+            # if colors and normals are OK save them
+            if vc is not None:
+                try:
+                    # may fail on a malformed color mask
+                    mesh['vertex_colors'] = vc[mask_v]
+                except BaseException:
+                    log.warning('failed to load vertex_colors',
+                                exc_info=True)
+            if mask_vn is not None:
+                try:
+                    # may fail on a malformed mask
+                    mesh['vertex_normals'] = vn[mask_vn]
+                except BaseException:
+                    log.warning('failed to load vertex_normals',
+                                exc_info=True)
         visual = None
         if material in materials:
             # use the material with the UV coordinates
@@ -735,7 +759,7 @@ def export_obj(mesh,
       Include vertex normals in export
     include_color : bool
       Include vertex color in export
-    include_texture bool
+    include_texture : bool
       Include `vt` texture in file text
     return_texture : bool
       If True, return a dict with texture files
@@ -768,6 +792,8 @@ def export_obj(mesh,
         meshes = [mesh]
     elif util.is_instance_named(mesh, 'Scene'):
         meshes = mesh.dump()
+    elif util.is_instance_named(mesh, 'PointCloud'):
+        meshes = [mesh]
     else:
         raise ValueError('must be Trimesh or Scene!')
 
@@ -775,11 +801,16 @@ def export_obj(mesh,
 
     counts = {'v': 0, 'vn': 0, 'vt': 0}
 
+    tex_data = None
+
     for mesh in meshes:
         # we are going to reference face_formats with this
         face_type = ['v']
         # OBJ includes vertex color as RGB elements on the same line
-        if include_color and mesh.visual.kind in ['vertex', 'face']:
+        if (include_color and
+            mesh.visual.kind in ['vertex', 'face'] and
+                len(mesh.visual.vertex_colors)):
+
             # create a stacked blob with position and color
             v_blob = np.column_stack((
                 mesh.vertices,
@@ -797,43 +828,55 @@ def export_obj(mesh,
                 row_delim='\nv ',
                 digits=digits)])
         # only include vertex normals if they're already stored
-        if include_normals and 'vertex_normals' in mesh._cache.cache:
-            # if vertex normals are stored in cache export them
-            face_type.append('vn')
-            export.append('vn ' + util.array_to_string(
-                mesh.vertex_normals,
-                col_delim=' ',
-                row_delim='\nvn ',
-                digits=digits))
+        if include_normals and mesh._cache.cache.get('vertex_normals') is not None:
+
+            try:
+                converted = util.array_to_string(
+                    mesh.vertex_normals,
+                    col_delim=' ',
+                    row_delim='\nvn ',
+                    digits=digits)
+                # if vertex normals are stored in cache export them
+                face_type.append('vn')
+                export.append('vn ' + converted)
+            except BaseException:
+                log.debug('failed to convert vertex normals',
+                          exc_info=True)
 
-        tex_data = None
         if include_texture and hasattr(mesh.visual, 'uv'):
-            # if vertex texture exists and is the right shape
-            face_type.append('vt')
-            # add the uv coordinates
-            export.append('vt ' + util.array_to_string(
-                mesh.visual.uv,
-                col_delim=' ',
-                row_delim='\nvt ',
-                digits=digits))
-            material = mesh.visual.material
-            if hasattr(material, 'to_simple'):
-                material = material.to_simple()
-            (tex_data,
-             tex_name,
-             mtl_name) = material.to_obj()
-            # add the reference to the MTL file
-            objects.appendleft('mtllib {}'.format(mtl_name))
-            # add the directive to use the exported material
-            export.appendleft('usemtl {}'.format(tex_name))
+            try:
+                material = mesh.visual.material
+                if hasattr(material, 'to_simple'):
+                    material = material.to_simple()
+                (tex_data,
+                 tex_name,
+                 mtl_name) = material.to_obj()
+                converted = util.array_to_string(
+                    mesh.visual.uv,
+                    col_delim=' ',
+                    row_delim='\nvt ',
+                    digits=digits)
+                # if vertex texture exists and is the right shape
+                face_type.append('vt')
+                # add the uv coordinates
+                export.append('vt ' + converted)
+                # add the reference to the MTL file
+                objects.appendleft('mtllib {}'.format(mtl_name))
+                # add the directive to use the exported material
+                export.appendleft('usemtl {}'.format(tex_name))
+            except BaseException:
+                log.debug('failed to convert UV coordinates',
+                          exc_info=True)
+
         # the format for a single vertex reference of a face
         face_format = face_formats[tuple(face_type)]
-        # add the exported faces to the export
-        export.append('f ' + util.array_to_string(
-            mesh.faces + 1 + counts['v'],
-            col_delim=' ',
-            row_delim='\nf ',
-            value_format=face_format))
+        # add the exported faces to the export if available
+        if hasattr(mesh, 'faces'):
+            export.append('f ' + util.array_to_string(
+                mesh.faces + 1 + counts['v'],
+                col_delim=' ',
+                row_delim='\nf ',
+                value_format=face_format))
         # offset our vertex position
         counts['v'] += len(mesh.vertices)
 
